/v1/projects — GNS3 1.3.dev1 documentation

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »

# /v1/projects

Contents

- /v1/projects
  - POST /v1/projects
    - Response status codes
    - Input
    - Output

## POST /v1/projects

Create a new project on the server

### Response status codes

- 200: OK

### Input

Name | Mandatory | Type | Description
--- | --- | --- | ---
path |  | ['string', 'null'] | Project directory
project_id |  | ['string', 'null'] | Project UUID
temporary |  | boolean | If project is a temporary project

### Output

Name | Mandatory | Type | Description
--- | --- | --- | ---
location | ✔ | string | Base directory where the project should be created on remote server
path |  | string | Directory of the project on the server
project_id | ✔ | string | Project UUID
temporary | ✔ | boolean | If project is a temporary project

### Navigation

- index
- next |
- previous |
- GNS3 1.3.dev1 documentation »